An S4 class representing the outputs of the LeMans model
NAn array with dimensions nsc, nfish and tot_time representing the number of individuals in each length class at each time step of the model.
CatchAn array with dimensions nsc, nfish and tot_time representing the biomass of each species that is caught in each length class at each time step of the model.
M2An array with dimensions nsc, nfish and tot_time representing the predation mortality of each species in each length class at each time step of the model.
RA matrix with dimensions tot_time and nfish representing the number of recruits of each species at each time step of the model.